Crate crypto_botters_binance

Crate crypto_botters_binance 

A crate for communicating with the Binance API. For example usages, see files in the examples/ directory.

Structs

BinanceError
BinanceOptions
A struct that represents a set of BinanceOption s.
BinanceRequestHandler
A struct that implements RequestHandler
BinanceWebSocketHandler
A struct that implements WebSocketHandler

Enums

BinanceAuth
BinanceHandlerError
BinanceHttpUrl
A enum that represents the base url of the Binance REST API.
BinanceOption
Options that can be set when creating handlers
BinanceWebSocketUrl
A enum that represents the base url of the Binance WebSocket API

Type Aliases

BinanceRequestError
BinanceRequestResult
The type returned by Client::request().