A crate for communicating with the Binance API. For example usages, see files in the examples/ directory.
Structs
- Binance
Error - Binance
Options - A
structthat represents a set of BinanceOption s. - Binance
Request Handler - A
structthat implements RequestHandler - Binance
WebSocket Handler - A
structthat implements WebSocketHandler
Enums
- Binance
Auth - Binance
Handler Error - Binance
Http Url - A
enumthat represents the base url of the Binance REST API. - Binance
Option - Options that can be set when creating handlers
- Binance
WebSocket Url - A
enumthat represents the base url of the Binance WebSocket API
Type Aliases
- Binance
Request Error - Binance
Request Result - The type returned by Client::request().